@@ -14,6 +14,8 @@ from .do import (
     JobDO,
     JobSettingDO,
     NamespaceDO,
+    NodeCreationItemDO,
+    NodeCreationRequestDO,
     NodeInfoDO,
     NodeMetaDO, 
     NodeUserSettingDO,
@@ -58,8 +60,8 @@ class K3SController:
     @exception_class_dec(max_try=1)
     def create_node(self, condition: ConditionDO, node_user_setting: NodeUserSettingDO, timeout=1200):
         data = {
-            "condition": condition.to_json(),
-            "node_user_setting": node_user_setting.to_json()
+            "condition": condition.dict(),
+            "node_user_setting": node_user_setting.dict()
         }
         data = json.dumps(data)
         response=requests.post(f'{self.url}/node', headers=self.header, data=data, timeout=timeout)
@@ -72,7 +74,7 @@ class K3SController:
 
     @exception_class_dec(max_try=1)
     def delete_nodes(self, node_infos: List[Union[NodeInfoDO, NodeMetaDO]], timeout=60):
-        data = [info.to_json() for info in node_infos]
+        data = [info.dict() for info in node_infos]
         data = json.dumps(data)
         response=requests.delete(f'{self.url}/nodes', headers=self.header, data=data, timeout=timeout)
         info = json.loads(response.text)
@@ -81,7 +83,7 @@ class K3SController:
 
     @exception_class_dec(max_try=1)
     def get_instance_info_by_node_meta(self, region_id: str, node_meta: NodeMetaDO, timeout=300):
-        data = json.dumps(node_meta.to_json())
+        data = json.dumps(node_meta.dict())
         response=requests.get(f'{self.url}/instance/region_id/{region_id}/node_meta', 
             headers=self.header, data=data, timeout=timeout)
         info = json.loads(response.text)
@@ -453,95 +455,62 @@ class K3SController:
         self._check_error(response.status_code, info)
         return info
 
+    @exception_class_dec()
+    def send_node_creation_request(self, request: NodeCreationRequestDO, timeout=3):
+        data = json.dumps(request.dict())
+        response=requests.post(f'{self.url}/node/request', 
+            headers=self.header, data=data, timeout=timeout)
+        id = json.loads(response.text)
+        self._check_error(response.status_code, id)
+        if id is None:
+            return None
+        else:
+            return id
 
-repo_info = \
-{
-    "K3SRepository":{
-        "add_node_label":{
-            "args":[["node_infos", True, "NodeInfo", None, True], ["key", False], ["value", False]],
-            "ret":["command_result", True, None, None, True, True]
-        },
-        "check_connection":{
-            "args":[],
-            "ret":["bool", False, None, None, False, True]
-        },
-        "create_config_maps":{
-            "args":[["cluster_name", False, "Name"], ["config_map_user_settings", True, "ConfigMapUserSetting", None, True]]
-        },
-        "create_namespace":{
-            "args":[["cluster_name", False, "Name"], ["namespace_name", False, "Name"]]
-        },
-        "create_node":{
-            "args":["condition", "node_user_setting"],
-            "ret":["node_info", True, None, None, False, True]
-        },
-        "create_resource_from_oss":{
-            "args":[["cluster_name", False, "Name"], ["target_paths", False, "Path", None, True]]
-        },
-        "create_secrets":{
-            "args":[["cluster_name", False, "Name"], ["secret_user_settings", True, "SecretUserSetting", None, True]]
-        },
-        "delete_nodes":{
-            "args":[["node_infos", True, "NodeInfo", None, True]]
-        },
-        "delete_resource_from_oss":{
-            "args":[["cluster_name", False, "Name"], ["target_paths", False, "Path", None, True]]
-        },
-        "get_config_maps":{
-            "args":[["cluster_name", False, "Name"], ["namespace_name", False, "Name"]],
-            "ret":["config_map", True, None, None, True, True],
-            "key": "{cluster_name.get_value()}:{namespace_name.get_value()}:config_maps"
-        },
-        "get_deployments":{
-            "args":[["cluster_name", False, "Name"], ["namespace_name", False, "Name"]],
-            "ret":["deployment", True, None, None, True, True],
-            "key": "{cluster_name.get_value()}:{namespace_name.get_value()}:deployments"
-        },
-        "get_instance_info_by_node_meta":{
-            "args":[["region_id", False], ["node_meta"]],
-            "key": "{region_id.get_value()}:{node_name.get_value()}:{node_ip.get_value}:instance_and_instance_type_info"
-        },
-        "get_existing_nodes":{
-            "args":[["cluster_name", False, "Name"]],
-            "ret":["node_info", True, None, None, True, True],
-            "key": "{cluster_name.get_value()}:existing_nodes"
-        },
-        "get_existing_nodes_by_name":{
-            "args":[["node_name", False, "Name"]],
-            "ret":["node_info", True, None, None, True, True],
-            "key": "{node_name.get_value()}:existing_nodes"
-        },
-        "get_namespaces":{
-            "args":[["cluster_name", False, "Name"]],
-            "ret":["namespace", True, None, None, True, True],
-            "key": "{cluster_name.get_value()}:namespaces"
-        },
-        "get_ingresses":{
-            "args":[["cluster_name", False, "Name"], ["namespace_name", False, "Name"]],
-            "ret":["ingress", True, None, None, True, True],
-            "key": "{cluster_name.get_value()}:{namespace_name.get_value()}:ingresses"
-        },
-        "get_node_metas":{
-            "args":[["cluster_name", False, "Name"]],
-            "ret":["node_meta", True, None, None, True, True],
-            "key": "{cluster_name.get_value()}:node_metas"
-        },
-        "get_pods":{
-            "args":[["cluster_name", False, "Name"], ["namespace_name", False, "Name"]],
-            "ret":["pod", True, None, None, True, True],
-            "key": "{cluster_name.get_value()}:{namespace_name.get_value()}:pods"
-        },
-        "get_secrets":{
-            "args":[["cluster_name", False, "Name"], ["namespace_name", False, "Name"]],
-            "ret":["secret", True, None, None, True, True],
-            "key": "{cluster_name.get_value()}:{namespace_name.get_value()}:secrets"
-        },
-        "upload_to_oss_from_pod":{
-            "args":[["pod_oss_operation_info", True, "PodOSSOperationInfo", None, False, False, "pod_oss_operation_info_converter"]]
-        }
-    }
-}
+    @exception_class_dec()
+    def find_node_creation_item(self, id: str, timeout=3):
+        response=requests.get(f'{self.url}/node/item/id/{id}', 
+            headers=self.header, timeout=timeout)
+        item = json.loads(response.text)
+        self._check_error(response.status_code, item)
+        if item is None:
+            return None
+        else:
+            return NodeCreationItemDO(**item)
 
-        
-        
+    @exception_class_dec()
+    def find_unprocessed_node_creation_item(self, timeout=3):
+        response=requests.get(f'{self.url}/node/item/unprocessed', 
+            headers=self.header, timeout=timeout)
+        item = json.loads(response.text)
+        self._check_error(response.status_code, item)
+        if item is None:
+            return None
+        else:
+            return NodeCreationItemDO(**item)
+
+    @exception_class_dec()
+    def update_node_creation_item(self, item:NodeCreationItemDO, timeout=10):
+        data = json.dumps(item.dict())
+        response=requests.put(f'{self.url}/node/item', 
+            headers=self.header, data=data, timeout=timeout)
+        succeed = json.loads(response.text)
+        self._check_error(response.status_code, succeed)
+        return succeed
+
+    @exception_class_dec()
+    def clear_node_creation_item(self, timeout=3):
+        response=requests.get(f'{self.url}/node/item/clear', 
+            headers=self.header, timeout=timeout)
+        n = json.loads(response.text)
+        self._check_error(response.status_code, n)
+        return n
+
+    @exception_class_dec()
+    def delete_node_creation_item(self, item_id:str, timeout=3):
+        response=requests.delete(f'{self.url}/node/item/id/{item_id}', 
+            headers=self.header, timeout=timeout)
+        succeed = json.loads(response.text)
+        self._check_error(response.status_code, succeed)
+        return succeed
 
