@@ -4,8 +4,7 @@ from typing import Dict, List, Optional, Union
 from ddd_objects.infrastructure.do import BaseDO
 from pydantic import BaseModel
 
-@dataclass
-class ConditionDO(BaseDO):
+class ConditionDO(BaseModel):
     min_cpu_num: int
     max_cpu_num: int
     min_memory_size: int
@@ -15,8 +14,7 @@ class ConditionDO(BaseDO):
     min_gpu_memory_size: Optional[int]=None
     max_gpu_memory_size: Optional[int]=None
 
-@dataclass
-class NodeUserSettingDO(BaseDO):
+class NodeUserSettingDO(BaseModel):
     name: str
     k3s_token: Optional[str]=None
     region_id: str='cn-zhangjiakou'
@@ -33,8 +31,7 @@ class NodeUserSettingDO(BaseDO):
     inner_connection: bool=True
     amount: int=1
 
-@dataclass
-class NodeInfoDO(BaseDO):
+class NodeInfoDO(BaseModel):
     node_name: str
     node_type: str
     node_status: str
@@ -70,6 +67,20 @@ class NodeInfoDO(BaseDO):
     k3s_version: Optional[str]=None
     _life_time: int=5
 
+class NodeCreationRequestDO(BaseModel):
+    condition: ConditionDO
+    node_user_setting: NodeUserSettingDO
+
+class NodeCreationItemDO(BaseModel):
+    id: str
+    node_creation_request: Optional[NodeCreationRequestDO]
+    status: str
+    creation_time: str
+    details: Optional[List[NodeInfoDO]]=None
+    entry_time: Optional[str]=None
+    exit_time: Optional[str]=None
+    _life_time: int=86400
+
 @dataclass
 class CommandResultDO(BaseDO):
     output: str
@@ -149,8 +160,7 @@ class PodOSSOperationInfoDO(BaseDO):
     target_dir: str
     local_path: str
 
-@dataclass
-class NodeMetaDO(BaseDO):
+class NodeMetaDO(BaseModel):
     name: str
     status: str
     run_time: str
